==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/dc9/strings__type_8h.js <==
var strings__type_8h =
[
    [ "StringID", "d4/dc9/strings__type_8h.html#a0041e63d7e56ded5697444aef740fa54", null ],
    [ "SpecialStrings", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0", [
      [ "SPECSTR_TOWNNAME_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ac3253b9b36e6a89cebb16382d0e6be96", null ],
      [ "SPECSTR_TOWNNAME_ENGLISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a11d26098396ec4f6d2cd6021d35cb4de", null ],
      [ "SPECSTR_TOWNNAME_FRENCH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a1d47a63ec73513df4b2fed514bcf1f8f", null ],
      [ "SPECSTR_TOWNNAME_GERMAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a0c1d7193bcd90592e426984cd19fda50", null ],
      [ "SPECSTR_TOWNNAME_AMERICAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a4c758639c5c69beec7b4019c5bd659ec", null ],
      [ "SPECSTR_TOWNNAME_LATIN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ae741f450e5ab6dbc1f399b532a6cb322", null ],
      [ "SPECSTR_TOWNNAME_SILLY", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ac4867ed6beec7c2e637e2690f3ecc1bc", null ],
      [ "SPECSTR_TOWNNAME_SWEDISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0afec92c7c6849b154c441db0686a69adf", null ],
      [ "SPECSTR_TOWNNAME_DUTCH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a92f79e32ef1bb0d866ac70dfc7b3756d", null ],
      [ "SPECSTR_TOWNNAME_FINNISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0add54f06e5e02440ea443bc243a8a6ea2", null ],
      [ "SPECSTR_TOWNNAME_POLISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6dcc4fb135239c5cdd9346886ac32492", null ],
      [ "SPECSTR_TOWNNAME_SLOVAK", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6ce4bee92c73717d1dda999e5bce021c", null ],
      [ "SPECSTR_TOWNNAME_NORWEGIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ada63cee523f8ef03525aaf10d61fa235", null ],
      [ "SPECSTR_TOWNNAME_HUNGARIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a0baf63e51b12e92362b5136c747936a2", null ],
      [ "SPECSTR_TOWNNAME_AUSTRIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a511484bca391939dfb7312fa33d416df", null ],
      [ "SPECSTR_TOWNNAME_ROMANIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6b4785a62d494ff531229709a0c4a518", null ],
      [ "SPECSTR_TOWNNAME_CZECH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a3f4e1e751d45460875a6b6f2a06109e5", null ],
      [ "SPECSTR_TOWNNAME_SWISS", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a314ff14f9c2825491eb02ed51304115b", null ],
      [ "SPECSTR_TOWNNAME_DANISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a72d71e9c375f6fa966b6f2a71b7ffbe9", null ],
      [ "SPECSTR_TOWNNAME_TURKISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa991367c2c377ab0cb330a28c7a01f25", null ],
      [ "SPECSTR_TOWNNAME_ITALIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a4142b624f68f2f43475ab99cfaf98e89", null ],
      [ "SPECSTR_TOWNNAME_CATALAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a1c9016c60a843b1a511a1c486fd29c1d", null ],
      [ "SPECSTR_TOWNNAME_LAST", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a29a6b3c294c00b17766ccf7d70d4bc10", null ],
      [ "SPECSTR_COMPANY_NAME_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a9cddee1aa8c2382bdc115e8870cf46a0", null ],
      [ "SPECSTR_COMPANY_NAME_LAST", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a965afa4a007d43bbb8043c3301393def", null ],
      [ "SPECSTR_SILLY_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a5b21e1795401368ee0fd7d81bd1f85ed", null ],
      [ "SPECSTR_ANDCO_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a9c0bbd24f9f18b3d7d27ad685a41956a", null ],
      [ "SPECSTR_PRESIDENT_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa7d92f8af7603b190dcfe4522dd54faf", null ],
      [ "SPECSTR_LANGUAGE_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aaeffe0c381b1fad3e1310f5ce4911513", null ],
      [ "SPECSTR_LANGUAGE_END", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa0c1e1004dbc7d5d70a1bad01ebe6739", null ],
      [ "SPECSTR_RESOLUTION_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a624c9bbdf6cb46fc6f2458518bd8b27b", null ],
      [ "SPECSTR_RESOLUTION_END", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0accbdbfab4751a2ec2178e20cf908a0d2", null ]
    ] ],
    [ "StringTab", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672", [
      [ "TEXT_TAB_TOWN", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672ad29fa594df741bf8ddf73b59f011f125", null ],
      [ "TEXT_TAB_INDUSTRY", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672adc3cb6fb730cc74c2abb1445646b1448", null ],
      [ "TEXT_TAB_STATION", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672aeb0518025f687903001f2c3506c1a73a", null ],
      [ "TEXT_TAB_SPECIAL", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a81bb4df0385323d0c1f50184fb2502ca", null ],
      [ "TEXT_TAB_OLD_CUSTOM", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a0e120d57640df9a1d1b8281ef2360ca5", null ],
      [ "TEXT_TAB_VEHICLE", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672adaf4713bec1175bcf3c1026786187f3b", null ],
      [ "TEXT_TAB_OLD_NEWGRF", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672aa05efe36ee84d8c808aa3f6452008e35", null ],
      [ "TEXT_TAB_END", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672ab73faa922019bfc6ebd80f97e314cd0f", null ],
      [ "TEXT_TAB_GAMESCRIPT_START", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a1111cfe53fa87a525373f0405701f5b3", null ],
      [ "TEXT_TAB_NEWGRF_START", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a07566672baa0942dce2f2b427d0cbd1a", null ]
    ] ],
    [ "TextDirection", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93", [
      [ "TD_LTR", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93a94fff229e29e2967ccf09035a19f1cf9", null ],
      [ "TD_RTL", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93ac4f8e28a509a16d112088b97f12346fb", null ]
    ] ],
    [ "INVALID_STRING_ID", "d4/dc9/strings__type_8h.html#a33692fa86918df7601b2f60d6bfb049b", null ],
    [ "MAX_CHAR_LENGTH", "d4/dc9/strings__type_8h.html#af40590177ad5f436ad655b0e94d82fce", null ],
    [ "MAX_LANG", "d4/dc9/strings__type_8h.html#a6b3118eea52573b89ae69804bf6e3f80", null ],
    [ "TAB_SIZE", "d4/dc9/strings__type_8h.html#ad3d086e19bd5b71e587846eb71d212ce", null ],
    [ "TAB_SIZE_BITS", "d4/dc9/strings__type_8h.html#a8c4d0bfbcecacc7383131dbdfb4d9c33", null ],
    [ "TAB_SIZE_GAMESCRIPT", "d4/dc9/strings__type_8h.html#a64d02365e8980cb9ac85a061c58036f4", null ],
    [ "TAB_SIZE_NEWGRF", "d4/dc9/strings__type_8h.html#a48b1fdbeed0da9a66d5c4dc41aa3107a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/dc9/strings__type_8h.js <==
var strings__type_8h =
[
    [ "StringID", "d4/dc9/strings__type_8h.html#a0041e63d7e56ded5697444aef740fa54", null ],
    [ "SpecialStrings", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0", [
      [ "SPECSTR_TOWNNAME_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ac3253b9b36e6a89cebb16382d0e6be96", null ],
      [ "SPECSTR_TOWNNAME_ENGLISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a11d26098396ec4f6d2cd6021d35cb4de", null ],
      [ "SPECSTR_TOWNNAME_FRENCH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a1d47a63ec73513df4b2fed514bcf1f8f", null ],
      [ "SPECSTR_TOWNNAME_GERMAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a0c1d7193bcd90592e426984cd19fda50", null ],
      [ "SPECSTR_TOWNNAME_AMERICAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a4c758639c5c69beec7b4019c5bd659ec", null ],
      [ "SPECSTR_TOWNNAME_LATIN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ae741f450e5ab6dbc1f399b532a6cb322", null ],
      [ "SPECSTR_TOWNNAME_SILLY", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ac4867ed6beec7c2e637e2690f3ecc1bc", null ],
      [ "SPECSTR_TOWNNAME_SWEDISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0afec92c7c6849b154c441db0686a69adf", null ],
      [ "SPECSTR_TOWNNAME_DUTCH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a92f79e32ef1bb0d866ac70dfc7b3756d", null ],
      [ "SPECSTR_TOWNNAME_FINNISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0add54f06e5e02440ea443bc243a8a6ea2", null ],
      [ "SPECSTR_TOWNNAME_POLISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6dcc4fb135239c5cdd9346886ac32492", null ],
      [ "SPECSTR_TOWNNAME_SLOVAK", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6ce4bee92c73717d1dda999e5bce021c", null ],
      [ "SPECSTR_TOWNNAME_NORWEGIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0ada63cee523f8ef03525aaf10d61fa235", null ],
      [ "SPECSTR_TOWNNAME_HUNGARIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a0baf63e51b12e92362b5136c747936a2", null ],
      [ "SPECSTR_TOWNNAME_AUSTRIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a511484bca391939dfb7312fa33d416df", null ],
      [ "SPECSTR_TOWNNAME_ROMANIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a6b4785a62d494ff531229709a0c4a518", null ],
      [ "SPECSTR_TOWNNAME_CZECH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a3f4e1e751d45460875a6b6f2a06109e5", null ],
      [ "SPECSTR_TOWNNAME_SWISS", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a314ff14f9c2825491eb02ed51304115b", null ],
      [ "SPECSTR_TOWNNAME_DANISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a72d71e9c375f6fa966b6f2a71b7ffbe9", null ],
      [ "SPECSTR_TOWNNAME_TURKISH", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa991367c2c377ab0cb330a28c7a01f25", null ],
      [ "SPECSTR_TOWNNAME_ITALIAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a4142b624f68f2f43475ab99cfaf98e89", null ],
      [ "SPECSTR_TOWNNAME_CATALAN", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a1c9016c60a843b1a511a1c486fd29c1d", null ],
      [ "SPECSTR_TOWNNAME_LAST", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a29a6b3c294c00b17766ccf7d70d4bc10", null ],
      [ "SPECSTR_COMPANY_NAME_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a9cddee1aa8c2382bdc115e8870cf46a0", null ],
      [ "SPECSTR_COMPANY_NAME_LAST", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a965afa4a007d43bbb8043c3301393def", null ],
      [ "SPECSTR_SILLY_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a5b21e1795401368ee0fd7d81bd1f85ed", null ],
      [ "SPECSTR_ANDCO_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a9c0bbd24f9f18b3d7d27ad685a41956a", null ],
      [ "SPECSTR_PRESIDENT_NAME", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa7d92f8af7603b190dcfe4522dd54faf", null ],
      [ "SPECSTR_LANGUAGE_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aaeffe0c381b1fad3e1310f5ce4911513", null ],
      [ "SPECSTR_LANGUAGE_END", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0aa0c1e1004dbc7d5d70a1bad01ebe6739", null ],
      [ "SPECSTR_RESOLUTION_START", "d4/dc9/strings__type_8h.html#ad650e8bed820ad593329a6ba032d33c0a624c9bbdf6cb46fc6f2458518bd8b27b", null ]
    ] ],
    [ "StringTab", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672", [
      [ "TEXT_TAB_TOWN", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672ad29fa594df741bf8ddf73b59f011f125", null ],
      [ "TEXT_TAB_INDUSTRY", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672adc3cb6fb730cc74c2abb1445646b1448", null ],
      [ "TEXT_TAB_STATION", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672aeb0518025f687903001f2c3506c1a73a", null ],
      [ "TEXT_TAB_SPECIAL", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a81bb4df0385323d0c1f50184fb2502ca", null ],
      [ "TEXT_TAB_OLD_CUSTOM", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a0e120d57640df9a1d1b8281ef2360ca5", null ],
      [ "TEXT_TAB_VEHICLE", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672adaf4713bec1175bcf3c1026786187f3b", null ],
      [ "TEXT_TAB_OLD_NEWGRF", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672aa05efe36ee84d8c808aa3f6452008e35", null ],
      [ "TEXT_TAB_END", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672ab73faa922019bfc6ebd80f97e314cd0f", null ],
      [ "TEXT_TAB_GAMESCRIPT_START", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a1111cfe53fa87a525373f0405701f5b3", null ],
      [ "TEXT_TAB_NEWGRF_START", "d4/dc9/strings__type_8h.html#ae948c08805d0e8ac9e138c6ae466e672a07566672baa0942dce2f2b427d0cbd1a", null ]
    ] ],
    [ "TextDirection", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93", [
      [ "TD_LTR", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93a94fff229e29e2967ccf09035a19f1cf9", null ],
      [ "TD_RTL", "d4/dc9/strings__type_8h.html#a1227460955e8a4f0bb75e779c057da93ac4f8e28a509a16d112088b97f12346fb", null ]
    ] ],
    [ "INVALID_STRING_ID", "d4/dc9/strings__type_8h.html#a33692fa86918df7601b2f60d6bfb049b", null ],
    [ "MAX_CHAR_LENGTH", "d4/dc9/strings__type_8h.html#af40590177ad5f436ad655b0e94d82fce", null ],
    [ "MAX_LANG", "d4/dc9/strings__type_8h.html#a6b3118eea52573b89ae69804bf6e3f80", null ],
    [ "TAB_SIZE", "d4/dc9/strings__type_8h.html#ad3d086e19bd5b71e587846eb71d212ce", null ],
    [ "TAB_SIZE_BITS", "d4/dc9/strings__type_8h.html#a8c4d0bfbcecacc7383131dbdfb4d9c33", null ],
    [ "TAB_SIZE_GAMESCRIPT", "d4/dc9/strings__type_8h.html#a64d02365e8980cb9ac85a061c58036f4", null ],
    [ "TAB_SIZE_NEWGRF", "d4/dc9/strings__type_8h.html#a48b1fdbeed0da9a66d5c4dc41aa3107a", null ]
];
